TerminologyServiceErrorClass class

TerminologyServiceErrorClass

Constructors

TerminologyServiceErrorClass(String? rawValue, {Element? element, FhirString? id, List<FhirExtension>? extension_, bool? disallowExtensions, String? system, String? version, String? display})
Factory constructor to create a new instance of TerminologyServiceErrorClass with the specified parameters.
factory
TerminologyServiceErrorClass.fromJson(Map<String, dynamic> json)
Factory constructor to create TerminologyServiceErrorClass from JSON.
factory

Properties

allExtensions List<FhirExtension>?
Returns a list of all extensions, including those in element.
no setterinherited
codeUnits List<int>
Returns the code units as a list of ints.
no setterinherited
copyWith TerminologyServiceErrorClassCopyWithImpl<TerminologyServiceErrorClass>
Creates a modified copy with updated properties.
no setter
disallowExtensions bool?
This is used in the FHIRPath engine to record that no extensions are allowed for this item in the context in which it is used. to do: enforce this....
finalinherited
display → FhirString?
display A representation of the meaning of the code in the system, following the rules of the system.
finalinherited
element → Element?
Optional FHIR metadata element (usually carrying extensions).
finalinherited
extension_ List<FhirExtension>?
List of extensions for additional information.
finalinherited
fhirType String
Returns "code".
no setterinherited
hasElement bool
Returns true if element is non-null.
no setterinherited
hashCode int
Hash code override.
no setterinherited
hasId bool
Getter for checking if the element has an id.
no setterinherited
hasPrimitiveValue bool
Checks if the object has a primitive value.
no setterinherited
hasValue bool
Returns true if valueString is non-null.
no setterinherited
hasValueAndElement bool
Returns true if both valueString and element are non-null.
no setterinherited
id → FhirString?
Unique id for the element within a resource.
finalinherited
isEmptyString bool
Checks if the string is empty.
no setterinherited
isMetadataBased bool
All Elements are metadata based.
no setterinherited
isNotEmpty bool
Checks if the string is not empty.
no setterinherited
isPrimitive bool
Checks if the object is primitive.
no setterinherited
length int
The length of the string (or 0 if null).
no setterinherited
primitiveValue String?
The primitive value as a String.
no setterinherited
runes Runes?
Returns the runes (Unicode code points).
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringBased bool
Returns true if the Type is considered string-based, otherwise false
no setterinherited
system → FhirUri?
system The identification of the code system that defines the meaning of the symbol in the code.
finalinherited
valueString String?
The primitive FHIR value as a String.
finalinherited
version → FhirString?
version The version of the code system which was used when choosing this code. Note that a well-maintained code system does not need the version reported, because the meaning of codes is consistent across versions. However this cannot consistently be assured, and when the meaning is not guaranteed to be consistent, the version SHOULD be exchanged.
finalinherited

Methods

addExtension(FhirExtension ext) → void
Method to add an extension.
inherited
clone() TerminologyServiceErrorClass
Clones the current instance.
codeUnitAt(int index) int?
Returns the code unit at the specified index.
inherited
compareDeep(FhirBase? e1, FhirBase? e2, [bool allowNull = false]) bool
Compares two FhirBase objects deeply using JSON comparison. This method converts both objects to JSON and compares the resulting structures, which catches all differences including those in nested objects.
inherited
compareDeepLists<T extends FhirBase>(List<T>? e1, List<T>? e2, bool allowNull) bool
Compares two lists with optional null/empty handling.
inherited
compareDeepStrings(String? s1, String? s2, bool allowNull) bool
Checks if the object is equal to another object.
inherited
contains(Pattern pattern, [int startIndex = 0]) bool
Checks if pattern occurs in the string.
inherited
endsWith(String other) bool
Checks if the string ends with other.
inherited
equals(Object other) bool
Convenience method matching equalsDeep, except for checking userData.
inherited
equalsDeep(FhirBase? other) bool
Deep equality check.
inherited
equalsDeepWithNull(FhirBase? obj1, FhirBase? obj2) bool
Deeply compares two FhirBase objects, either of which can be null. This is a convenience method that handles null checking before calling equalsDeep.
inherited
equalsShallow(FhirBase other) bool
By default, shallow equality checks only valueString.
inherited
getChildByName(String name) → FhirBase?
Retrieves a property by name, or if its a list that contains only one element, returns that element.
inherited
getChildrenByName(String name, [bool checkValid = false]) List<FhirBase>
Retrieves the properties of the object.
inherited
getExtensionFirstRep() → FhirExtension
Getter for the first extension.
inherited
getExtensionsByUrl(String url) List<FhirExtension>
Getter for the first extension by url.
inherited
hasExtension() bool
Extension handling methods.
inherited
hasExtensionByUrl(String url) bool
Method to check if an extension exists by url.
inherited
hasType(List<String> names) bool
Checks if the object has a given type.
inherited
hasValues() bool
Checks if the object has values.
inherited
indexOf(Pattern pattern, [int start = 0]) int
Finds the first occurrence of pattern.
inherited
isAs<T extends FhirBase>() → T?
Returns an Object cast as a Type if it is that type.
inherited
isEmpty() bool
Checks if the object is empty.
inherited
isInfrastructure() bool
Determines if the error type is related to infrastructure issues.
lastIndexOf(Pattern pattern, [int? start]) int
Finds the last occurrence of pattern.
inherited
listChildrenNames() List<String>
Lists the JSON keys for the object.
inherited
listEquals<T extends FhirBase>(List<T>? list1, List<T>? list2) bool
Compares two lists of FhirBase objects for equality. Returns true if both lists are null, or if they have the same length and all corresponding elements are deeply equal.
inherited
noExtensions() → FhirString
Returns a copy with disallowExtensions set to true.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padLeft(int width, [String padding = ' ']) String
Pads left side to width with padding.
inherited
padRight(int width, [String padding = ' ']) String
Pads right side to width with padding.
inherited
prettyPrint() String
Converts the object to a pretty JSON string.
inherited
removeExtension(String url) → void
Method to remove an extension by url.
inherited
replaceAll(Pattern from, String replace) String
Replaces all occurrences of from with replace.
inherited
replaceAllMapped(Pattern from, String replace(Match)) String
Replaces all occurrences with a mapped function.
inherited
replaceFirst(Pattern from, String to, [int startIndex = 0]) String
Replaces the first occurrence of from with to.
inherited
replaceFirstMapped(Pattern from, String replace(Match), [int startIndex = 0]) String
Replaces the first occurrence with a mapped function.
inherited
replaceRange(int start, int? end, String replacement) String
Replaces a range start..end with replacement.
inherited
split(Pattern pattern) List<String>
Splits this string on pattern.
inherited
splitMapJoin(Pattern pattern, {String onMatch(Match)?, String onNonMatch(String)?}) String
Splits the string on pattern, calling onMatch / onNonMatch.
inherited
startsWith(Pattern pattern, [int index = 0]) bool
Checks if the string starts with pattern.
inherited
substring(int start, [int? end]) String
Substring of valueString from start to optional end.
inherited
toJson() Map<String, dynamic>
Serializes the instance to JSON with standardized keys.
toJsonString() String
Converts the object to a JSON string.
inherited
toLowerCase() String
Converts the string to lower case.
inherited
toString() String
String representation.
toUpperCase() String
Converts the string to upper case.
inherited
toYaml() String
Converts the object to a YAML string.
inherited
trim() String
Returns the valueString trimmed of whitespace.
inherited
trimLeft() String
Trims left side whitespace.
inherited
trimRight() String
Trims right side whitespace.
inherited
withElement(Element? newElement) TerminologyServiceErrorClass
Returns the enum value with an element attached.

Operators

operator +(String other) String
Concatenates this with other.
inherited
operator ==(Object other) bool
Equality operator override.
inherited
operator [](int index) String
Returns the character at the specified index.
inherited

Static Properties

blockedByOptions TerminologyServiceErrorClass
The operation is blocked by specific validation options.
final
codeSystemUnsupported TerminologyServiceErrorClass
The code system is unsupported.
final
elementOnly TerminologyServiceErrorClass
For instances where an Element is present but not value.
final
noservice TerminologyServiceErrorClass
Indicates no terminology service is available.
final
serverError TerminologyServiceErrorClass
An error occurred on the server.
final
unknown TerminologyServiceErrorClass
Unknown error type.
final
values List<TerminologyServiceErrorClass>
List of all enum-like values.
final
valueSetUnsupported TerminologyServiceErrorClass
The value set is unsupported.
final