FhirPathException class
Something went wrong while parsing or executing a FHIRPath expression.
- Inheritance
-
- Object
- PathEngineException
- FhirPathException
- Implemented types
- Implementers
Constructors
- FhirPathException(String message, {String? pathExpression, int? offset, Object? token, Object? cause, String? operation, dynamic arguments, List? collection, Object? context, Map? environment, SourceLocation? location})
- Constructs a new FhirPathException.
Properties
- arguments → dynamic
-
The arguments to a function or operator at the time of the issue
final
- cause → Object?
-
The cause of the exception.
finalinherited
- collection → List?
-
The intermediate results collection at the time of the issue
final
- context → Object?
-
The original node that was passed to the evaluation engine before
starting evaluation
final
- environment → Map?
-
Environment which was present
final
- expression → String?
-
The FHIRPath expression being evaluated when the exception occurred.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Optional identifier for the exception.
finalinherited
- location → SourceLocation?
-
The location in the FHIRPath where the exception occurred.
finalinherited
- message → String?
-
The exception message.
finalinherited
- offset → int?
-
Optional offset in the expression where the issue occurred
final
- operation → String?
-
Which function or operator was causing the issue
final
- pathExpression → String?
-
Which expression is having the issue
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the time of the exception.
finalinherited
- token → Object?
-
Which token was causing the issue
final
Methods
-
copyWith(
{Object? context, Map? variables}) → FhirPathException - Creates a new FhirPathException with the given parameters.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toShortString(
) → String - Returns a short string representation of the exception.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited