disallowExtensions property
This is used in the FHIRPath engine to record that no extensions are allowed for this item in the context in which it is used. to do: enforce this....
Implementation
final bool? disallowExtensions;
This is used in the FHIRPath engine to record that no extensions are allowed for this item in the context in which it is used. to do: enforce this....
final bool? disallowExtensions;